@@ -3,7 +3,7 @@
 """ Top-level module for xcollection. """
 from pkg_resources import DistributionNotFound, get_distribution
 
-from .main import Collection
+from .main import Collection, open_collection
 
 try:
     __version__ = get_distribution('xcollection').version
